@@ -38,20 +38,21 @@ static void f5_key_prog(int x)
                   " Virtual W/Z decays          OF5"
                   " Parallelization          nCORES";  
         
-    if(VVdecay)  improveStr(strmen,"OF5","ON ");
+    if(VWdecay)  improveStr(strmen,"OF5","ON ");
         else     improveStr(strmen,"OF5","OFF");    
-    improveStr(strmen,"nCORES","%d",nCORES);    
+    improveStr(strmen,"nCORES","%d",nPROCSS);    
                                           
     menu1(20,18,"Switches",strmen,"s_switch_*",&pscr,&kmenu);
     if(kmenu==1) 
-    {  VVdecay=!VVdecay;
-       if(checkParam()>0){VVdecay=!VVdecay;checkParam();};
+    {  VWdecay=!VWdecay;
+       if(checkParam()>0){VWdecay=!VWdecay;checkParam();};
     } else if(kmenu==2) 
     { char mess[40];
       sprintf(mess,"There are %d processors. To use ", (int) sysconf(_SC_NPROCESSORS_ONLN));
-      correctInt(20,22,mess,&nCORES,1);
+      correctInt(20,22,mess,&nPROCSS,1);
     }    
-  }                     
+  }
+  VZdecay=VWdecay;                     
 }
 
 
@@ -163,7 +164,7 @@ int main(int argc,char** argv)
   link_process(PtrInterface_ext);  
   
   start1(title,icon,"calchep.ini;../calchep.ini",&xw_error);
-  nCORES=sysconf(_SC_NPROCESSORS_ONLN); 
+  nPROCSS=sysconf(_SC_NPROCESSORS_ONLN); 
 
   if(r_sess__(NULL)==-1)
   { 
@@ -198,6 +199,9 @@ int main(int argc,char** argv)
         inkeyString=inkeyString0;
      }   
   }
+  { char *ch=getenv("nParProc");
+    if(ch) sscanf(ch,"%d",&nPROCSS);
+  }  
   
   goto_xy(10,10); print("Calculation of constraints.  Please, be patient.");
   escpressed();
