@@ -63,9 +63,9 @@ static void writeEvent(double *x,  int n)
       sqme_int(Nsub,GG,pvectR,cb_coeff,&err);
          
       for(i=0;i<cb_pow;i++) sum+=fabs(cb_coeff[i]);
-     if(nCORES) pthread_mutex_lock(&drandXX_key);
+     if(nPROCSS) pthread_mutex_lock(&drandXX_key);
       sum*=drandXX();
-     if(nCORES) pthread_mutex_unlock(&drandXX_key);
+     if(nPROCSS) pthread_mutex_unlock(&drandXX_key);
       for(i=0;i<cb_pow;i++)
       { sum-=fabs(cb_coeff[i]);
         if(sum<=0) break;
@@ -75,7 +75,7 @@ static void writeEvent(double *x,  int n)
       if(cb_coeff!=cb_coeff_) free(cb_coeff);
    } 
 
-   if(nCORES)pthread_mutex_lock(&wrt_key);   
+   if(nPROCSS)pthread_mutex_lock(&wrt_key);   
    fprintf(events_,"%8d ",n);  
    if(nin_int==2) fprintf(events_," %17.10E %17.10E",pvect[3],pvect[7]);
 
@@ -95,7 +95,7 @@ static void writeEvent(double *x,  int n)
    }
    fprintf(events_,"\n");
 //   fflush(events_);     
-   if(nCORES)pthread_mutex_unlock(&wrt_key);
+   if(nPROCSS)pthread_mutex_unlock(&wrt_key);
 }
 
 //static long n_cube=1000;
@@ -103,21 +103,21 @@ static void writeEvent(double *x,  int n)
 long EventGrid=10000;
 
 
-static long nRandom=100;
-static long nSimplex1=50;
-static long nEvents=10000;
+
+static int regen=1; 
+static int nEvents=10000;
 static double max =1.2;
 static double milk=0.1; 
 
 int saveEventSettings(FILE * f)
 {
-  fprintf(f, "%ld %ld %ld %ld ",n_cube, nRandom, nSimplex1,  nEvents);
+  fprintf(f, "%d %d %d ",n_cube, regen,  nEvents);
   return 0;
 }
 
 int  readEventSettings(FILE * f)
 {
-  fscanf(f, "%ld %ld %ld %ld %ld ", &n_cube, &nRandom, &nSimplex1, &nEvents);
+  fscanf(f, "%d %d %d ", &n_cube, &regen, &nEvents);
   return 0;
 }
 
@@ -174,7 +174,6 @@ static void  generateEvents( vegasGrid * vegPtr,  char *fname,  FILE * iprt)
 {                                                   
    int mode=1;
    void * pscr=NULL;
-   static int regen=1; 
 //   if(!vegPtr->fMax)improveEvents(vegPtr,func);
     
    for(mode=1;;)
@@ -189,7 +188,7 @@ static void  generateEvents( vegasGrid * vegPtr,  char *fname,  FILE * iprt)
      menu1(53,10,"",strmen,"n_gen_*",&pscr,&mode);
      switch(mode)
      { case 0: return; 
-       case 1: correctLong(50,15,"",&nEvents,1); break;
+       case 1: correctInt(50,15,"",&nEvents,1); break;
        case 2: 
        { long  nGenerated=0; 
          double eff;
@@ -204,7 +203,7 @@ static void  generateEvents( vegasGrid * vegPtr,  char *fname,  FILE * iprt)
          if(ftell(events_)==0) write_event_cap();
          fileEnd=ftell(events_);
          fflush(events_); 
-         cEvent= vegas_events(vegPtr,nEvents,max,writeEvent,regen,nCORES,&stat); //   &eff,&nmax,&mult,&neg);
+         cEvent= vegas_events(vegPtr,nEvents,max,writeEvent,regen,nPROCSS,&stat); //   &eff,&nmax,&mult,&neg);
          eff=stat.eff; neg=stat.neg; mult=stat.lmax;
          fclose(events_);
 
@@ -231,9 +230,9 @@ static void  generateEvents( vegasGrid * vegPtr,  char *fname,  FILE * iprt)
                fscanf(events_,"%ld",&nGenerated);
                nGenerated+=cEvent;
                fseek(events_,nEvPos,SEEK_SET);
-               fprintf(events_," %10d",nGenerated);
+               fprintf(events_," %10ld",nGenerated);
                fclose(events_);
-               fprintf(iprt," %d events are stored in '%s'\n",nGenerated,fname);
+               fprintf(iprt," %ld events are stored in '%s'\n",nGenerated,fname);
                fprintf(iprt,"%s\n",mess);
                fflush(iprt);
             } else  truncate(fname,fileEnd);
@@ -322,7 +321,7 @@ int saveVegasGrid( FILE * f)
      }
      if(veg_Ptr->fMax)
      { long l;
-       fprintf(f,"Max(%d):\n",veg_Ptr->evnCubes);
+       fprintf(f,"Max(%ld):\n",veg_Ptr->evnCubes);
        for(l=0;l<veg_Ptr->evnCubes;l++) fprintf(f,"%.1E\n",veg_Ptr->fMax[l]);
      } else fprintf(f,"Max(0):\n");
   }else  fprintf(f," Vegas_grid: dim=%d  size=%d\n", 0, 0);
@@ -414,9 +413,9 @@ static double func_(double *x, double wgt)
     if(ret_val<0) negPoints+=ret_val*wgt;
 exi:
     if(hFill)
-    { if(nCORES) pthread_mutex_lock(&hist_key);
+    { if(nPROCSS) pthread_mutex_lock(&hist_key);
        fillHists(ret_val*wgt,pvect); 
-      if(nCORES) pthread_mutex_unlock(&hist_key); 
+      if(nPROCSS) pthread_mutex_unlock(&hist_key); 
     } 
     return ret_val;
 } /* func_ */
@@ -515,7 +514,7 @@ int runVegas(void)
             negPoints=0;                                                              
             badPoints=0; 
             hFill=1;   
-            nCall=vegas_int(veg_Ptr, integral.ncall[0],1.5*(!integral.freeze),nCORES,&avgi, &sd);
+            nCall=vegas_int(veg_Ptr, integral.ncall[0],1.5*(!integral.freeze),nPROCSS,&avgi, &sd);
             if(nCall<0) { messanykey(10,10,"NaN in integrand"); break;}
             if(nCall==0) break;
             
