@@ -2,6 +2,7 @@
  Copyright (C) 1997, Alexander Pukhov 
 */
 #include <math.h>
+
 #include"interface.h"
 #include"sf_epa.h"
 #include"sf_isr.h"
@@ -139,9 +140,13 @@ int sf_menu(int i)
     return 1;
 } /* sf_menu__ */
 
+
 double strfun_(int i, double x,double q)
-{ double ff=strFun[sf_num[i-1]-1].val(i,x,q);
-  if( !finite(ff) ) 
+{ double ff;
+
+   ff=strFun[sf_num[i-1]-1].val(i,x,q);
+
+  if( !isfinite(ff) ) 
   {
     if(nnan[i-1]==0) printf("Distribution function of %d^th particle returns NAN   at x=%E Q=%E\n",i,x,q);
     if(nnan[i-1]==100) printf("More than 100 times distribution function of %d^th particle returns NAN\n",i); 
