@@ -1134,10 +1134,11 @@ exi:;
 static int find3charge(void)
 {
   int i,cont;
+  for(i=0;i<nparticles;i++) if(prtclbase[i].nHerm) prtclbase[i].q3=0;
 
   for(cont=1;cont;)
   { cont=0;  
-    for(i=0;i<nparticles;i++) if(prtclbase[i].hlp!='*' &&   ghostmother(i+1)==i+1 && prtclbase[i].q3==unknownQ3)
+    for(i=0;i<nparticles;i++) if(/*prtclbase[i].hlp!='*' && */  ghostmother(i+1)==i+1 && prtclbase[i].q3==unknownQ3)
     { decaylink dec=prtclbase[i].top;
       for(;dec;dec=dec->next)
       { int j,ch,br ;
@@ -1286,7 +1287,7 @@ static void readEXTFunc(FILE*f)
   for(;fgets(buff,199,f);)
   { 
     trim(buff);
-    if(strstr(buff,"extern ")==buff);
+    if(strstr(buff,"extern ")==buff)
     { char *c;
       c=strchr(buff,'(');
       if(c)
@@ -1372,7 +1373,7 @@ int makeVandP(int rd ,char*path,int L, int mode,char*CalcHEP)
       fprintf(f," {\"%s\",",prtclbase[i].name);
       if(i+1==anti)   fprintf(f,"\"%s\", ",prtclbase[i].name);
            else       fprintf(f,"\"%s\", ",prtclbase[anti-1].name);
-     fprintf(f,"%ld, \"%s\",\"%s\",%d,%d,%d}\n",
+     fprintf(f,"%d, \"%s\",\"%s\",%d,%d,%d}\n",
        prtclbase[i].N,  prtclbase[i].massidnt, prtclbase[i].imassidnt,  
        prtclbase[i].spin, prtclbase[i].cdim,prtclbase[i].q3);
     
