@@ -30,7 +30,7 @@
 #include "numcheck.h"
 #include "../../include/version.h"
 #include "dynamic_cs.h"
-#include "pubvar.h"
+#include "n_proc.h"
 
 static int errorcode=0;
 
@@ -378,16 +378,16 @@ restart2:
 
             menulevel=4;
                         
-            if(!nParProc ) calcallproc(); else 
-            { int *pids=malloc(sizeof(int)*nParProc);
-              int *pipes=malloc(2*sizeof(int)*nParProc);
-              int **qd=malloc(sizeof(int*)*nParProc);
-              int totD=sqDiagList(qd, nParProc);
+            if(!nPROCSS ) calcallproc(); else 
+            { int *pids=malloc(sizeof(int)*nPROCSS);
+              int *pipes=malloc(2*sizeof(int)*nPROCSS);
+              int **qd=malloc(sizeof(int*)*nPROCSS);
+              int totD=sqDiagList(qd, nPROCSS);
               int totC,nProc;
               int k;
               
               fflush(NULL);
-              for(k=0;k<nParProc;k++) 
+              for(k=0;k<nPROCSS;k++) 
               { int* kpipe=pipes+2*k;
                 pipe(kpipe);
                 pids[k]=fork();
@@ -398,13 +398,13 @@ restart2:
                   exit(0);
                 }
               }
-              for(k=0;k<nParProc;k++) close(pipes[2*k+1]);
+              for(k=0;k<nPROCSS;k++) close(pipes[2*k+1]);
               infoLine(0.);
-              for(nProc=nParProc,totC=0;nProc;)
+              for(nProc=nPROCSS,totC=0;nProc;)
               { int one;
                 int err;
                 nProc=0;
-                for(k=0;k<nParProc;k++) if(pids[k])
+                for(k=0;k<nPROCSS;k++) if(pids[k])
                 { if(waitpid(pids[k],NULL,WNOHANG)==0)
                   {  nProc++; 
                      if(read(pipes[2*k],&one,sizeof(int)))totC+=one;
@@ -413,10 +413,10 @@ restart2:
                      pids[k]=0;
                   }
                 }  
-                if(infoLine((double)totC/(double)totD)) for(k=0;k<nParProc;k++) if(pids[k]) kill(pids[k],SIGUSR1);   
+                if(infoLine((double)totC/(double)totD)) for(k=0;k<nPROCSS;k++) if(pids[k]) kill(pids[k],SIGUSR1);   
               }  
               infoLine(2);
-              for(k=0;k<nParProc;k++)
+              for(k=0;k<nPROCSS;k++)
               { char ctlgName[100];
                 char command[200];
                 sprintf(ctlgName,"%s_%d",CATALOG_NAME,k);
@@ -429,10 +429,10 @@ restart2:
               if(totC)  newCodes=1;  
               updateMenuQ();
               
-              for(k=0;k<nParProc;k++) close(pipes[2*k]);
+              for(k=0;k<nPROCSS;k++) close(pipes[2*k]);
               free(pids);   
               free(pipes);
-              for(k=0;k<nParProc;k++) free(qd[k]);
+              for(k=0;k<nPROCSS;k++) free(qd[k]);
               free(qd);   
             }
             
@@ -498,7 +498,7 @@ label_50:
           n_calchep_id=setLockFile("results/.lock"); 
            if(n_calchep_id)
            {
-             if(nParProc)
+             if(nPROCSS)
              { chdir("results"); 
                 makeVandP(0,"../models",n_model,2,pathtocalchep);
                pCompile();
