@@ -6,7 +6,7 @@
 #include <dirent.h>
 #include <pthread.h>
 
-#include "pubvar.h"
+#include "n_proc.h"
 
 #include"syst.h"
 #include"syst2.h" 
@@ -29,12 +29,12 @@ void wrt_menu(int menutype,int k,char*txt,int ndel,int ncalc,int nrest,long recp
    if (menutype == 1)
    {
       fseek(menup,(k - 1)*71 + 2,SEEK_SET);
-      fprintf(menup,"%4d| %-44.44s|%5d|%5d|%-8d",k,txt,ndel,nrest,recpos);
+      fprintf(menup,"%4d| %-44.44s|%5d|%5d|%-8ld",k,txt,ndel,nrest,recpos);
    }
    else
    {
       fseek(menuq,(k - 1)*77 + 2,SEEK_SET);
-      fprintf(menuq,"%4d| %-44.44s|%5d|%5d|%5d|%-8d",k,txt,ndel,ncalc,nrest,recpos);
+      fprintf(menuq,"%4d| %-44.44s|%5d|%5d|%5d|%-8ld",k,txt,ndel,ncalc,nrest,recpos);
    }
 }
 
@@ -161,13 +161,13 @@ int pCompile(void)
   closedir(dirPtr);
   N=0;
   if(fN)
-  {  pthread_t *threads = malloc(nParProc*sizeof(pthread_t));
-     int*num=malloc(nParProc*sizeof(int));
+  {  pthread_t *threads = malloc(nPROCSS*sizeof(pthread_t));
+     int*num=malloc(nPROCSS*sizeof(int));
      pthread_t control;  
-     for (k=0;k<nParProc;k++) num[k]=k+1;  
-     for (k=0;k<nParProc;k++) pthread_create(threads+k,NULL,pCompile_cycle, num+k);
+     for (k=0;k<nPROCSS;k++) num[k]=k+1;  
+     for (k=0;k<nPROCSS;k++) pthread_create(threads+k,NULL,pCompile_cycle, num+k);
       comp_control(NULL);     
-     for (k=0;k<nParProc;k++)   pthread_join(threads[k],NULL);
+     for (k=0;k<nPROCSS;k++)   pthread_join(threads[k],NULL);
      free(threads);
   }
   
